@@ -44,6 +44,7 @@ from PyFin.Math.Accumulators.StatelessAccumulators import Product
 from PyFin.Math.Accumulators.StatefulAccumulators import Shift
 from PyFin.Math.Accumulators.StatefulAccumulators import Delta
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverage
+from PyFin.Math.Accumulators.StatefulAccumulators import TimeMovingAverage
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingDecay
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingPositiveAverage
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeAverage
@@ -55,6 +56,7 @@ from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedPositive
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedNegative
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingVariance
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingStandardDeviation
+from PyFin.Math.Accumulators.StatefulAccumulators import TimeMovingStandardDeviation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeVariance
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMax
@@ -114,6 +116,7 @@ __all__ = ["Exp",
            "IIF",
            "Identity",
            "MovingAverage",
+           "TimeMovingAverage",
            "MovingDecay",
            "MovingPositiveAverage",
            "MovingNegativeAverage",
@@ -139,6 +142,7 @@ __all__ = ["Exp",
            "MovingAnyTrue",
            "MovingVariance",
            "MovingStandardDeviation",
+           "TimeMovingStandardDeviation",
            "MovingLogReturn",
            "MovingResidue",
            "MovingSharp",
