@@ -32,6 +32,7 @@ from PyFin.Math.Accumulators import TimeMovingCountUnique
 from PyFin.Math.Accumulators import MovingAllTrue
 from PyFin.Math.Accumulators import MovingAnyTrue
 from PyFin.Math.Accumulators import MovingAverage
+from PyFin.Math.Accumulators import TimeMovingAverage
 from PyFin.Math.Accumulators import MovingDecay
 from PyFin.Math.Accumulators import MovingPositiveAverage
 from PyFin.Math.Accumulators import MovingNegativeAverage
@@ -43,6 +44,7 @@ from PyFin.Math.Accumulators import MovingCountedPositive
 from PyFin.Math.Accumulators import MovingCountedNegative
 from PyFin.Math.Accumulators import MovingVariance
 from PyFin.Math.Accumulators import MovingStandardDeviation
+from PyFin.Math.Accumulators import TimeMovingStandardDeviation
 from PyFin.Math.Accumulators import MovingNegativeVariance
 from PyFin.Math.Accumulators import MovingCorrelation
 from PyFin.Math.Accumulators import MovingProduct
@@ -221,6 +223,25 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                                  "Average calculated: {2:f}".format(i, expected,
                                                                                                     calculated))
 
+    def testTimeMovingAverager(self):
+        window = 60
+
+        mv = TimeMovingAverage(window, 'z')
+        values = np.random.randn(2500)
+        stamps = np.cumsum(np.random.randint(1, 10, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mv.push(dict(z=value, stamp=stamp))
+
+            calculated = mv.result()
+            time_diff = (stamp - stamps) < window
+            time_diff[i+1:] = False
+            expected = np.mean(values[time_diff])
+
+            self.assertAlmostEqual(calculated, expected, 12,
+                                   "at index {0}\n"
+                                   "expected:   {1}\n"
+                                   "calculated: {2}".format(i, expected, calculated))
+
     def testMovingDecay(self):
         window = 80
         total = 2500
@@ -828,7 +849,7 @@ class TestStatefulAccumulators(unittest.TestCase):
         window = 60
         mat = TimeMovingCount(window, Latest("x"))
         values = np.random.randn(2500)
-        stamps = np.cumsum(np.random.randint(0, 10, 2500))
+        stamps = np.cumsum(np.random.randint(1, 10, 2500))
         for i, (value, stamp) in enumerate(zip(values, stamps)):
             mat.push(dict(x=value, stamp=stamp))
 
@@ -1327,6 +1348,41 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                                  "Var calculated: {2:f}".format(i, expected,
                                                                                                 calculated))
 
+    def testTimeMovingStandardDeviation(self):
+        window = 60
+
+        mv = TimeMovingStandardDeviation(window, 'z', isPopulation=True)
+        values = np.random.randn(2500)
+        stamps = np.cumsum(np.random.randint(1, 10, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mv.push(dict(z=value, stamp=stamp))
+
+            calculated = mv.result()
+            time_diff = (stamp - stamps) < window
+            time_diff[i+1:] = False
+            expected = np.std(values[time_diff])
+
+            if i >= window - 1:
+                self.assertAlmostEqual(calculated, expected, 12,
+                                       "at index {0}\n"
+                                       "expected:   {1}\n"
+                                       "calculated: {2}".format(i, expected, calculated))
+
+        mv = TimeMovingStandardDeviation(window, 'z', isPopulation=False)
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mv.push(dict(z=value, stamp=stamp))
+
+            calculated = mv.result()
+            time_diff = (stamp - stamps) < window
+            time_diff[i + 1:] = False
+            expected = np.std(values[time_diff], ddof=1)
+
+            if i >= window - 1:
+                self.assertAlmostEqual(calculated, expected, 12,
+                                       "at index {0}\n"
+                                       "expected:   {1}\n"
+                                       "calculated: {2}".format(i, expected, calculated))
+
     def testMovingStandardDeviationDeepcopy(self):
         window = 20
         mv = MovingStandardDeviation(window, 'x')
